==> jsprit-core-1.7.3-sources.jar: com/graphhopper/jsprit/core/algorithm/RemoveEmptyVehicles.java <==
/*
 * Licensed to GraphHopper GmbH under one or more contributor
 * license agreements. See the NOTICE file distributed with this work for
 * additional information regarding copyright ownership.
 *
 * GraphHopper GmbH licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.graphhopper.jsprit.core.algorithm;

import com.graphhopper.jsprit.core.algorithm.recreate.listener.InsertionEndsListener;
import com.graphhopper.jsprit.core.problem.solution.route.VehicleRoute;
import com.graphhopper.jsprit.core.problem.vehicle.VehicleFleetManager;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;


public class RemoveEmptyVehicles implements InsertionEndsListener {

    private VehicleFleetManager fleetManager;

    public RemoveEmptyVehicles(VehicleFleetManager fleetManager) {
        super();
        this.fleetManager = fleetManager;
    }

    @Override
    public String toString() {
        return "[name=removeEmptyVehicles]";
    }

    @Override
    public void informInsertionEnds(Collection<VehicleRoute> vehicleRoutes) {
        List<VehicleRoute> routes = new ArrayList<VehicleRoute>(vehicleRoutes);
        for (VehicleRoute route : routes) {
            if (route.isEmpty()) {
                fleetManager.unlock(route.getVehicle());
                vehicleRoutes.remove(route);
            }
        }
    }
}

==> jsprit-core-1.8-sources.jar: com/graphhopper/jsprit/core/algorithm/RemoveEmptyVehicles.java <==
/*
 * Licensed to GraphHopper GmbH under one or more contributor
 * license agreements. See the NOTICE file distributed with this work for
 * additional information regarding copyright ownership.
 *
 * GraphHopper GmbH licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.graphhopper.jsprit.core.algorithm;

import com.graphhopper.jsprit.core.algorithm.recreate.listener.InsertionEndsListener;
import com.graphhopper.jsprit.core.problem.job.Job;
import com.graphhopper.jsprit.core.problem.solution.route.VehicleRoute;
import com.graphhopper.jsprit.core.problem.vehicle.VehicleFleetManager;

import java.util.Collection;
import java.util.Iterator;


public class RemoveEmptyVehicles implements InsertionEndsListener {

    private VehicleFleetManager fleetManager;

    public RemoveEmptyVehicles(VehicleFleetManager fleetManager) {
        super();
        this.fleetManager = fleetManager;
    }

    @Override
    public String toString() {
        return "[name=removeEmptyVehicles]";
    }

    @Override
    public void informInsertionEnds(Collection<VehicleRoute> vehicleRoutes, Collection<Job> badJobs) {
        for (Iterator<VehicleRoute> iterator = vehicleRoutes.iterator(); iterator.hasNext(); ) {
            VehicleRoute route = iterator.next();
            if (route.isEmpty()) {
                fleetManager.unlock(route.getVehicle());
                iterator.remove();
            }
        }
    }
}
